@@ -515,7 +515,7 @@ GUI::GUI()
     connect(file_save_all_action, SIGNAL(triggered()), this, SLOT(file_save_all()));
     file_menu->addAction(file_save_all_action);
     QAction *file_close_action = new QAction(tr("&Close"), this);
-    file_close_action->setShortcut(tr("Ctrl+C"));
+    file_close_action->setShortcut(tr("Ctrl+W"));
     connect(file_close_action, SIGNAL(triggered()), this, SLOT(file_close()));
     file_menu->addAction(file_close_action);
     QAction *file_close_all_action = new QAction(tr("Close all"), this);
@@ -523,74 +523,94 @@ GUI::GUI()
     file_menu->addAction(file_close_all_action);
     file_menu->addSeparator();
     QMenu *file_import_menu = file_menu->addMenu(tr("Import"));
-    QAction *file_import_dcmtk_action = new QAction(tr("via DCMTK..."), this);
+    QAction *file_import_dcmtk_action = new QAction(tr("DICOM files (via DCMTK)..."), this);
     connect(file_import_dcmtk_action, SIGNAL(triggered()), this, SLOT(file_import_dcmtk()));
     if (!cmd_is_available(cmd_find("from-dcmtk")))
     {
         file_import_dcmtk_action->setEnabled(false);
     }
     file_import_menu->addAction(file_import_dcmtk_action);
-    QAction *file_import_exr_action = new QAction(tr("via EXR..."), this);
+    QAction *file_import_exr_action = new QAction(tr("EXR HDR images (via OpenEXR)..."), this);
     connect(file_import_exr_action, SIGNAL(triggered()), this, SLOT(file_import_exr()));
     if (!cmd_is_available(cmd_find("from-exr")))
     {
         file_import_exr_action->setEnabled(false);
     }
     file_import_menu->addAction(file_import_exr_action);
-    QAction *file_import_gdal_action = new QAction(tr("via GDAL..."), this);
+    QAction *file_import_gdal_action = new QAction(tr("Remote Sensing data (via GDAL)..."), this);
     connect(file_import_gdal_action, SIGNAL(triggered()), this, SLOT(file_import_gdal()));
     if (!cmd_is_available(cmd_find("from-gdal")))
     {
         file_import_gdal_action->setEnabled(false);
     }
     file_import_menu->addAction(file_import_gdal_action);
-    QAction *file_import_magick_action = new QAction(tr("via Magick..."), this);
+    QAction *file_import_magick_action = new QAction(tr("Image data (via ImageMagick)..."), this);
     connect(file_import_magick_action, SIGNAL(triggered()), this, SLOT(file_import_magick()));
     if (!cmd_is_available(cmd_find("from-magick")))
     {
         file_import_magick_action->setEnabled(false);
     }
     file_import_menu->addAction(file_import_magick_action);
-    QAction *file_import_pfs_action = new QAction(tr("via PFS..."), this);
+    QAction *file_import_mat_action = new QAction(tr("MATLAB data (via matio)..."), this);
+    connect(file_import_mat_action, SIGNAL(triggered()), this, SLOT(file_import_mat()));
+    if (!cmd_is_available(cmd_find("from-mat")))
+    {
+        file_import_mat_action->setEnabled(false);
+    }
+    file_import_menu->addAction(file_import_mat_action);
+    QAction *file_import_pfs_action = new QAction(tr("PFS floating point data (via PFS)..."), this);
     connect(file_import_pfs_action, SIGNAL(triggered()), this, SLOT(file_import_pfs()));
     if (!cmd_is_available(cmd_find("from-pfs")))
     {
         file_import_pfs_action->setEnabled(false);
     }
     file_import_menu->addAction(file_import_pfs_action);
-    QAction *file_import_raw_action = new QAction(tr("raw data..."), this);
+    QAction *file_import_rat_action = new QAction(tr("RAT RadarTools data..."), this);
+    connect(file_import_rat_action, SIGNAL(triggered()), this, SLOT(file_import_rat()));
+    file_import_menu->addAction(file_import_rat_action);
+    QAction *file_import_raw_action = new QAction(tr("Raw data..."), this);
     connect(file_import_raw_action, SIGNAL(triggered()), this, SLOT(file_import_raw()));
     file_import_menu->addAction(file_import_raw_action);
     QMenu *file_export_menu = file_menu->addMenu(tr("Export"));
-    QAction *file_export_exr_action = new QAction(tr("via EXR..."), this);
+    QAction *file_export_exr_action = new QAction(tr("EXR HDR images (via EXR)..."), this);
     connect(file_export_exr_action, SIGNAL(triggered()), this, SLOT(file_export_exr()));
     if (!cmd_is_available(cmd_find("to-exr")))
     {
         file_export_exr_action->setEnabled(false);
     }
     file_export_menu->addAction(file_export_exr_action);
-    QAction *file_export_gdal_action = new QAction(tr("via GDAL..."), this);
+    QAction *file_export_gdal_action = new QAction(tr("Remote Sensing data (via GDAL)..."), this);
     connect(file_export_gdal_action, SIGNAL(triggered()), this, SLOT(file_export_gdal()));
     if (!cmd_is_available(cmd_find("to-gdal")))
     {
         file_export_gdal_action->setEnabled(false);
     }
     file_export_menu->addAction(file_export_gdal_action);
-    QAction *file_export_magick_action = new QAction(tr("via Magick..."), this);
+    QAction *file_export_magick_action = new QAction(tr("Image data (via ImageMagick)..."), this);
     connect(file_export_magick_action, SIGNAL(triggered()), this, SLOT(file_export_magick()));
     if (!cmd_is_available(cmd_find("to-magick")))
     {
         file_export_magick_action->setEnabled(false);
     }
     file_export_menu->addAction(file_export_magick_action);
-    QAction *file_export_pfs_action = new QAction(tr("via PFS..."), this);
+    QAction *file_export_mat_action = new QAction(tr("MATLAB data (via matio)..."), this);
+    connect(file_export_mat_action, SIGNAL(triggered()), this, SLOT(file_export_mat()));
+    if (!cmd_is_available(cmd_find("to-mat")))
+    {
+        file_export_mat_action->setEnabled(false);
+    }
+    file_export_menu->addAction(file_export_mat_action);
+    QAction *file_export_pfs_action = new QAction(tr("PFS floating point data (via PFS)..."), this);
     connect(file_export_pfs_action, SIGNAL(triggered()), this, SLOT(file_export_pfs()));
     if (!cmd_is_available(cmd_find("to-pfs")))
     {
         file_export_pfs_action->setEnabled(false);
     }
     file_export_menu->addAction(file_export_pfs_action);
-    QAction *file_export_raw_action = new QAction(tr("raw data..."), this);
+    QAction *file_export_rat_action = new QAction(tr("RAT RadarTools data..."), this);
+    connect(file_export_rat_action, SIGNAL(triggered()), this, SLOT(file_export_rat()));
+    file_export_menu->addAction(file_export_rat_action);
+    QAction *file_export_raw_action = new QAction(tr("Raw data..."), this);
     connect(file_export_raw_action, SIGNAL(triggered()), this, SLOT(file_export_raw()));
     file_export_menu->addAction(file_export_raw_action);
     file_menu->addSeparator();
@@ -847,7 +867,8 @@ QString GUI::file_save_dialog(const QString &default_suffix, const QStringList &
             if (existing_fw->file_name().length() > 0)
             {
                 QFileInfo existing_file_info(cio::to_sys(existing_fw->file_name()).c_str());
-                if (file_info.canonicalFilePath() == existing_file_info.canonicalFilePath())
+                if (existing_file_info.canonicalFilePath().length() > 0
+                        && file_info.canonicalFilePath() == existing_file_info.canonicalFilePath())
                 {
                     QMessageBox::critical(this, "Error", "This file is currently opened. Close it first.");
                     file_name = QString();
@@ -941,11 +962,14 @@ int GUI::run(const std::string &cmd, const std::vector<std::string> &args,
     int cmd_index = cmd_find(cmd.c_str());
     cmd_open(cmd_index);
     std::string mbox_text = "<p>Running command</p><code>";
-    mbox_text += cmd + " ";
+    mbox_text += cmd;
+    /*
+    mbox_text + " ";
     for (size_t i = 0; i < args.size(); i++)
     {
         mbox_text += args[i] + " ";
     }
+    */
     mbox_text += "</code>";
     QDialog *mbox = new QDialog(this);
     mbox->setModal(true);
@@ -1016,8 +1040,11 @@ void GUI::output_cmd(const std::string &cmd, const std::vector<std::string> &arg
         if (retval != 0)
         {
             try { cio::remove(save_name); } catch (...) {}
-            std::string errmsg = "<p>Command failed.</p>";
+            std::string errmsg = "<p>Command <code>";
+            errmsg += cmd;
+            errmsg += "</code> failed.</p>";
             /*
+            std::string errmsg = "<p>Command failed.</p>";
             errmsg += "<p>Command line:</p><pre>";
             errmsg += cmd + " ";
             for (size_t i = 0; i < args.size(); i++)
@@ -1112,7 +1139,8 @@ void GUI::open(const std::string &file_name, const std::string &save_name)
             if (fw->file_name().length() > 0)
             {
                 QFileInfo existing_file_info(cio::to_sys(fw->file_name()).c_str());
-                if (file_info.canonicalFilePath() == existing_file_info.canonicalFilePath())
+                if (existing_file_info.canonicalFilePath().length() > 0
+                        && file_info.canonicalFilePath() == existing_file_info.canonicalFilePath())
                 {
                     _files_widget->setCurrentWidget(fw);
                     return;
@@ -1306,11 +1334,21 @@ void GUI::file_import_magick()
     import_from("from-magick", std::vector<std::string>(), QStringList("Typical image files (*.png *.jpg)"));
 }
 
+void GUI::file_import_mat()
+{
+    import_from("from-mat", std::vector<std::string>(), QStringList("MATLAB files (*.mat)"));
+}
+
 void GUI::file_import_pfs()
 {
     import_from("from-pfs", std::vector<std::string>(), QStringList("PFS files (*.pfs)"));
 }
 
+void GUI::file_import_rat()
+{
+    import_from("from-rat", std::vector<std::string>(), QStringList("RAT RadarTools files (*.rat)"));
+}
+
 void GUI::file_import_raw()
 {
     QDialog *dialog = new QDialog(this);
@@ -1369,6 +1407,16 @@ void GUI::file_export_magick()
     export_to("to-magick", std::vector<std::string>(), "png", QStringList("Typical image files (*.png *.jpg)"));
 }
 
+void GUI::file_export_mat()
+{
+    export_to("to-mat", std::vector<std::string>(), "mat", QStringList("MATLAB files (*.mat)"));
+}
+
+void GUI::file_export_rat()
+{
+    export_to("to-rat", std::vector<std::string>(), "rat", QStringList("RAT RadarTools files (*.rat)"));
+}
+
 void GUI::file_export_pfs()
 {
     export_to("to-pfs", std::vector<std::string>(), "pfs", QStringList("PFS files (*.pfs)"));
